aboutsummaryrefslogtreecommitdiff
path: root/libobjc/objc/objc-exception.h
diff options
context:
space:
mode:
authorNicola Pero <nicola.pero@meta-innovation.com>2010-09-11 12:38:56 +0000
committerNicola Pero <nicola@gcc.gnu.org>2010-09-11 12:38:56 +0000
commit3d0d87390b1aad25556c927130ef0ec6890439e8 (patch)
tree34a7ed63e36b5323657af9af9dc423fa5a37dd3e /libobjc/objc/objc-exception.h
parentf9132eb797d897b8e66b8e8ddb3e8e2744b6ac51 (diff)
downloadgcc-3d0d87390b1aad25556c927130ef0ec6890439e8.zip
gcc-3d0d87390b1aad25556c927130ef0ec6890439e8.tar.gz
gcc-3d0d87390b1aad25556c927130ef0ec6890439e8.tar.bz2
In libobjc:
* objc/deprecated/struct_objc_selector.h: New file. Definition of 'struct objc_selector' and 'sel_eq' moved here. * objc/deprecated/struct_objc_protocol.h: New file. Definition of 'struct objc_procotol' moved here. * objc/deprecated/struct_objc_class.h: New file. Definition of 'struct objc_class' moved here. * objc/deprecated/MetaClass.h: New file. Definition of MetClass moved here. * objc/deprecated/STR.h: New file. Definition of STR moved here. * objc/message.h: New file. Definitions for relval_t, apply_t, arglist, arglist_t and objc_msg_lookup were moved here. * objc/objc.h: Include the above files instead of defining the corresponding structs, types and functions here. Added new opaque definitions for SEL and Class. Use Class and not 'struct objc_class *' in the definition of 'struct objc_object'. Commented all types defined in the file. Removed special definition of BOOL as 'int' on __vxworks; use 'unsigned char' there as well. * objc/deprecated/objc-unexpected-exception.h: Renamed to objc_unexpected_exception.h. * objc/objc-api.h: Updated include of objc-unexpetected-exception.h * objc/objc-exception.h: Updated comments. * Makefile.in (OBJC_H, OBJC_DEPRECATED_H): Added the new header files. Reindented list of files. From-SVN: r164212
Diffstat (limited to 'libobjc/objc/objc-exception.h')
-rw-r--r--libobjc/objc/objc-exception.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libobjc/objc/objc-exception.h b/libobjc/objc/objc-exception.h
index 715152d..2fb9ba6 100644
--- a/libobjc/objc/objc-exception.h
+++ b/libobjc/objc/objc-exception.h
@@ -59,9 +59,9 @@ extern "C" {
*/
void objc_exception_throw (id exception);
-/* PS: the Apple runtime seems to also have objc_exception_rethrow(),
- objc_begin_catch() and objc_end_catch(). Currently the GNU runtime
- does not use them.
+/* Compatibility note: the Apple/NeXT runtime seems to also have
+ objc_exception_rethrow(), objc_begin_catch() and objc_end_catch().
+ Currently the GNU runtime does not use them.
*/
/* The following functions allow customizing to a certain extent the
@@ -73,8 +73,8 @@ void objc_exception_throw (id exception);
functions unless you are writing your own Foundation library.
*/
-/* PS: objc_set_exception_preprocessor() (available on the Apple
- runtime) is not supported on the GNU runtime. */
+/* Compatibility note: objc_set_exception_preprocessor() (available on
+ the Apple/NeXT runtime) is not available on the GNU runtime. */
/* An 'objc_exception_matcher' function is used to match an exception
to a @catch clause. 'catch_class' is the class of objects caught
@@ -106,7 +106,7 @@ objc_uncaught_exception_handler
objc_set_uncaught_exception_handler (objc_uncaught_exception_handler new_handler);
/* For compatibility with the Apple runtime. */
#define objc_setExceptionMatcher objc_set_exception_matcher
#define objc_setUncaughtExceptionHandler objc_set_uncaught_exception_handler
@@ -106,7 +106,7 @@ objc_uncaught_exception_handler
objc_set_uncaught_exception_handler (objc_uncaught_exception_handler new_handler);
-/* For compatibility with the Apple runtime. */
+/* For compatibility with the Apple/NeXT runtime. */
#define objc_setExceptionMatcher objc_set_exception_matcher
#define objc_setUncaughtExceptionHandler objc_set_uncaught_exception_handler